@@ -1,5 +1,4 @@
-"""
-Compatibility catboost module.
+"""Compatibility catboost module.
 
 In the future use:
     from wandb.integration.catboost import WandbCallback
