@@ -1,6 +1,7 @@
 """Batching file prepare requests to our API."""
 
 import concurrent.futures
+import functools
 import os
 import queue
 import shutil
@@ -29,6 +30,7 @@ class RequestStoreManifestFiles(NamedTuple):
     manifest: "artifacts.ArtifactManifest"
     artifact_id: str
     save_fn: "internal_artifacts.SaveFn"
+    save_fn_async: "internal_artifacts.SaveFnAsync"
 
 
 class RequestCommitArtifact(NamedTuple):
@@ -93,19 +95,12 @@ class StepChecksum:
                         req.copy,
                         None,
                         None,
+                        None,
                     )
                 )
             elif isinstance(req, RequestStoreManifestFiles):
                 for entry in req.manifest.entries.values():
                     if entry.local_path:
-                        # This stupid thing is needed so the closure works correctly.
-                        def make_save_fn_with_entry(
-                            save_fn: "internal_artifacts.SaveFn",
-                            entry: "artifacts.ArtifactManifestEntry",
-                        ) -> step_upload.SaveFn:
-                            return lambda progress_callback: save_fn(
-                                entry, progress_callback
-                            )
 
                         self._stats.init_file(
                             entry.local_path,
@@ -121,7 +116,8 @@ class StepChecksum:
                                 req.artifact_id,
                                 entry.digest,
                                 False,
-                                make_save_fn_with_entry(req.save_fn, entry),
+                                functools.partial(req.save_fn, entry),
+                                functools.partial(req.save_fn_async, entry),
                                 entry.digest,
                             )
                         )
