@@ -1,5 +1,6 @@
 """Batching file prepare requests to our API."""
 
+import asyncio
 import concurrent.futures
 import logging
 import queue
@@ -7,7 +8,7 @@ import sys
 import threading
 from typing import (
     TYPE_CHECKING,
-    Any,
+    Awaitable,
     Callable,
     MutableMapping,
     MutableSequence,
@@ -23,6 +24,7 @@ from wandb.filesync import upload_job
 if TYPE_CHECKING:
     from wandb.filesync import dir_watcher, stats
     from wandb.sdk.internal import file_stream, internal_api, progress
+    from wandb.sdk.internal.settings_static import SettingsStatic
 
     if sys.version_info >= (3, 8):
         from typing import TypedDict
@@ -39,7 +41,8 @@ if TYPE_CHECKING:
 
 PreCommitFn = Callable[[], None]
 OnRequestFinishFn = Callable[[], None]
-SaveFn = Callable[["progress.ProgressFn"], Any]
+SaveFn = Callable[["progress.ProgressFn"], bool]
+SaveFnAsync = Callable[["progress.ProgressFn"], Awaitable[bool]]
 
 logger = logging.getLogger(__name__)
 
@@ -51,6 +54,7 @@ class RequestUpload(NamedTuple):
     md5: Optional[str]
     copied: bool
     save_fn: Optional[SaveFn]
+    save_fn_async: Optional[SaveFnAsync]
     digest: Optional[str]
 
 
@@ -70,15 +74,56 @@ Event = Union[
 ]
 
 
+class AsyncExecutor:
+    """Runs async file uploads in a background thread."""
+
+    def __init__(
+        self,
+        pool: concurrent.futures.ThreadPoolExecutor,
+        concurrency_limit: Optional[int],
+    ) -> None:
+        self.loop = asyncio.new_event_loop()
+        self.loop.set_default_executor(pool)
+        self.loop_thread = threading.Thread(
+            target=self.loop.run_forever,
+            daemon=True,
+            name="wandb-upload-async",
+        )
+
+        self.concurrency_limiter = asyncio.Semaphore(
+            value=concurrency_limit or 128,
+            # Before Python 3.10: if we don't set `loop=loop`,
+            #   then the Semaphore will bind to the wrong event loop,
+            #   causing errors when a coroutine tries to wait for it;
+            #   see https://pastebin.com/XcrS9suX .
+            # After 3.10: the `loop` argument doesn't exist.
+            # So we need to only conditionally pass in `loop`.
+            **({} if sys.version_info >= (3, 10) else {"loop": self.loop}),
+        )
+
+    def start(self) -> None:
+        self.loop_thread.start()
+
+    def stop(self) -> None:
+        self.loop.call_soon_threadsafe(self.loop.stop)
+
+    def submit(self, coro: Awaitable[None]) -> None:
+        async def run_with_limiter() -> None:
+            async with self.concurrency_limiter:
+                await coro
+
+        asyncio.run_coroutine_threadsafe(run_with_limiter(), self.loop)
+
+
 class StepUpload:
     def __init__(
         self,
         api: "internal_api.Api",
         stats: "stats.Stats",
         event_queue: "queue.Queue[Event]",
-        max_jobs: int,
+        max_threads: int,
         file_stream: "file_stream.FileStreamApi",
-        silent: bool = False,
+        settings: Optional["SettingsStatic"] = None,
     ) -> None:
         self._api = api
         self._stats = stats
@@ -90,18 +135,25 @@ class StepUpload:
 
         self._pool = concurrent.futures.ThreadPoolExecutor(
             thread_name_prefix="wandb-upload",
-            max_workers=max_jobs,
+            max_workers=max_threads,
+        )
+
+        self._async_executor = (
+            AsyncExecutor(
+                pool=self._pool,
+                concurrency_limit=settings._async_upload_concurrency_limit,
+            )
+            if settings is not None and settings._async_upload_concurrency_limit
+            else None
         )
 
         # Indexed by files' `save_name`'s, which are their ID's in the Run.
-        self._running_jobs: MutableMapping[
-            dir_watcher.SaveName, upload_job.UploadJob
-        ] = {}
+        self._running_jobs: MutableMapping[dir_watcher.SaveName, RequestUpload] = {}
         self._pending_jobs: MutableSequence[RequestUpload] = []
 
         self._artifacts: MutableMapping[str, "ArtifactStatus"] = {}
 
-        self.silent = silent
+        self.silent = bool(settings.silent) if settings else False
 
     def _thread_body(self) -> None:
         event: Optional[Event]
@@ -129,6 +181,9 @@ class StepUpload:
                 self._handle_event(event)
             elif not self._running_jobs:
                 # Queue was empty and no jobs left.
+                self._pool.shutdown(wait=False)
+                if self._async_executor:
+                    self._async_executor.stop()
                 if finish_callback:
                     finish_callback()
                 break
@@ -186,24 +241,19 @@ class StepUpload:
             self._pending_jobs.append(event)
             return
 
-        # Start it.
-        job = upload_job.UploadJob(
-            self._stats,
-            self._api,
-            self._file_stream,
-            self.silent,
-            event.save_name,
-            event.path,
-            event.artifact_id,
-            event.md5,
-            event.copied,
-            event.save_fn,
-            event.digest,
-        )
-        self._spawn_upload(job)
+        if self._async_executor and event.save_fn_async is not None:
+            # (The `and save_fn_async is not None` is because the async code path
+            # doesn't support all uploads yet: even if the user has requested async,
+            # we sometimes need to use the sync method instead.)
+            self._spawn_upload_async(
+                event,
+                async_executor=self._async_executor,
+            )
+        else:
+            self._spawn_upload_sync(event)
 
-    def _spawn_upload(self, job: upload_job.UploadJob) -> None:
-        """Spawns an upload job, and handles the bookkeeping of `self._running_jobs`.
+    def _spawn_upload_sync(self, event: RequestUpload) -> None:
+        """Spawn an upload job, and handles the bookkeeping of `self._running_jobs`.
 
         Context: it's important that, whenever we add an entry to `self._running_jobs`,
         we ensure that a corresponding `EventJobDone` message will eventually get handled;
@@ -214,7 +264,6 @@ class StepUpload:
         to `self._running_jobs` is textually right next to the code that eventually enqueues
         the `EventJobDone` message. This should help keep them in sync.
         """
-
         # Adding the entry to `self._running_jobs` MUST happen in the main thread,
         # NOT in the job that gets submitted to the thread-pool, to guard against
         # this sequence of events:
@@ -228,18 +277,71 @@ class StepUpload:
         #
         # This would be very bad!
         # So, this line has to happen _outside_ the `pool.submit()`.
-        self._running_jobs[job.save_name] = job
+        self._running_jobs[event.save_name] = event
 
         def run_and_notify() -> None:
             try:
-                job.run()
+                self._do_upload_sync(event)
             finally:
                 self._event_queue.put(
-                    upload_job.EventJobDone(job=job, exc=sys.exc_info()[1])
+                    upload_job.EventJobDone(event, exc=sys.exc_info()[1])
                 )
 
         self._pool.submit(run_and_notify)
 
+    def _spawn_upload_async(
+        self,
+        event: RequestUpload,
+        async_executor: AsyncExecutor,
+    ) -> None:
+        """Equivalent to _spawn_upload_sync, but uses the async event loop instead of a thread, and requires `event.save_fn_async`.
+
+        Raises:
+            AssertionError: if `event.save_fn_async` is None.
+        """
+        assert event.save_fn_async is not None
+
+        self._running_jobs[event.save_name] = event
+
+        async def run_and_notify() -> None:
+            try:
+                await self._do_upload_async(event)
+            finally:
+                self._event_queue.put(
+                    upload_job.EventJobDone(event, exc=sys.exc_info()[1])
+                )
+
+        async_executor.submit(run_and_notify())
+
+    def _do_upload_sync(self, event: RequestUpload) -> None:
+        job = upload_job.UploadJob(
+            self._stats,
+            self._api,
+            self._file_stream,
+            self.silent,
+            event.save_name,
+            event.path,
+            event.artifact_id,
+            event.md5,
+            event.copied,
+            event.save_fn,
+            event.digest,
+        )
+        job.run()
+
+    async def _do_upload_async(self, event: RequestUpload) -> None:
+        """Upload a file and returns when it's done. Requires `event.save_fn_async`."""
+        assert event.save_fn_async is not None
+        job = upload_job.UploadJobAsync(
+            stats=self._stats,
+            api=self._api,
+            file_stream=self._file_stream,
+            silent=self.silent,
+            request=event,
+            save_fn_async=event.save_fn_async,
+        )
+        await job.run()
+
     def _init_artifact(self, artifact_id: str) -> None:
         self._artifacts[artifact_id] = {
             "finalize": False,
@@ -283,6 +385,8 @@ class StepUpload:
 
     def start(self) -> None:
         self._thread.start()
+        if self._async_executor:
+            self._async_executor.start()
 
     def is_alive(self) -> bool:
         return self._thread.is_alive()
