@@ -1,18 +1,17 @@
+import asyncio
 import logging
 import os
 from typing import TYPE_CHECKING, NamedTuple, Optional
 
 import wandb
-import wandb.util
 
 if TYPE_CHECKING:
-
     from wandb.filesync import dir_watcher, stats, step_upload
     from wandb.sdk.internal import file_stream, internal_api
 
 
 class EventJobDone(NamedTuple):
-    job: "UploadJob"
+    job: "step_upload.RequestUpload"
     exc: Optional[BaseException]
 
 
@@ -77,7 +76,7 @@ class UploadJob:
             except Exception as e:
                 self._stats.update_failed_file(self.save_path)
                 logger.exception("Failed to upload file: %s", self.save_path)
-                wandb.util.sentry_exc(e)
+                wandb._sentry.exception(e)
                 message = str(e)
                 # TODO: this is usually XML, but could be JSON
                 if hasattr(e, "response"):
@@ -139,7 +138,7 @@ class UploadJob:
             except Exception as e:
                 self._stats.update_failed_file(self.save_name)
                 logger.exception("Failed to upload file: %s", self.save_path)
-                wandb.util.sentry_exc(e)
+                wandb._sentry.exception(e)
                 if not self.silent:
                     wandb.termerror(
                         'Error uploading "{}": {}, {}'.format(
@@ -150,3 +149,75 @@ class UploadJob:
 
     def progress(self, total_bytes: int) -> None:
         self._stats.update_uploaded_file(self.save_name, total_bytes)
+
+
+class UploadJobAsync:
+    """Roughly an async equivalent of UploadJob.
+
+    Important differences:
+    - `run` is a coroutine
+    - If `run()` fails, it falls back to the synchronous UploadJob
+    """
+
+    def __init__(
+        self,
+        stats: "stats.Stats",
+        api: "internal_api.Api",
+        file_stream: "file_stream.FileStreamApi",
+        silent: bool,
+        request: "step_upload.RequestUpload",
+        save_fn_async: "step_upload.SaveFnAsync",
+    ) -> None:
+        self._stats = stats
+        self._api = api
+        self._file_stream = file_stream
+        self.silent = silent
+        self._request = request
+        self._save_fn_async = save_fn_async
+
+    async def run(self) -> None:
+        try:
+            deduped = await self._save_fn_async(
+                lambda _, t: self._stats.update_uploaded_file(self._request.path, t)
+            )
+        except Exception as e:
+            # Async uploads aren't yet (2023-01) battle-tested.
+            # Fall back to the "normal" synchronous upload.
+            loop = asyncio.get_event_loop()
+            logger.exception("async upload failed", exc_info=e)
+            loop.run_in_executor(None, wandb._sentry.exception, e)
+            wandb.termwarn(
+                "Async file upload failed; falling back to sync", repeat=False
+            )
+            sync_job = UploadJob(
+                self._stats,
+                self._api,
+                self._file_stream,
+                self.silent,
+                self._request.save_name,
+                self._request.path,
+                self._request.artifact_id,
+                self._request.md5,
+                self._request.copied,
+                self._request.save_fn,
+                self._request.digest,
+            )
+
+            await loop.run_in_executor(None, sync_job.run)
+        else:
+            self._file_stream.push_success(self._request.artifact_id, self._request.save_name)  # type: ignore
+
+            if deduped:
+                logger.info("Skipped uploading %s", self._request.path)
+                self._stats.set_file_deduped(self._request.path)
+            else:
+                logger.info("Uploaded file %s", self._request.path)
+        finally:
+            # If we fell back to the sync impl, the file will have already been deleted.
+            # Doesn't matter, we only try to delete it if it exists.
+            if self._request.copied:
+                try:
+                    os.remove(self._request.path)
+                except OSError:
+                    # The file has already been deleted, we don't have permissions, or something else we can't fix.
+                    pass
