@@ -1,6 +1,4 @@
-"""
-W&B callback for CatBoost
-"""
+"""W&B callback for CatBoost."""
 
 from .catboost import WandbCallback, log_summary
 
