@@ -25,17 +25,17 @@ patch_tf_keras()
 
 
 class WandbModelCheckpoint(callbacks.ModelCheckpoint):
-    """`WandbModelCheckpoint` periodically saves a Keras model or model weights
-    and uploads it to W&B as a `wandb.Artifact`.
+    """A checkpoint that periodically saves a Keras model or model weights.
 
-    Since this callback is subclassed from `tf.keras.callbacks.ModelCheckpoint`,
-    the checkpointing logic is taken care of by the parent callback. You can learn
-    more here:
-    https://www.tensorflow.org/api_docs/python/tf/keras/callbacks/ModelCheckpoint
+    Saves weights are uploaded to W&B as a `wandb.Artifact`.
 
-    This callback is to be used in conjunction with training using `model.fit()`
-    to save a model or weights (in a checkpoint file) at some interval. The
-    model checkpoints will be logged as W&B Artifacts. You can learn more here:
+    Since this callback is subclassed from `tf.keras.callbacks.ModelCheckpoint`, the
+    checkpointing logic is taken care of by the parent callback. You can learn more
+    here: https://www.tensorflow.org/api_docs/python/tf/keras/callbacks/ModelCheckpoint
+
+    This callback is to be used in conjunction with training using `model.fit()` to save
+    a model or weights (in a checkpoint file) at some interval. The model checkpoints
+    will be logged as W&B Artifacts. You can learn more here:
     https://docs.wandb.ai/guides/artifacts
 
     This callback provides the following features:
@@ -56,7 +56,6 @@ class WandbModelCheckpoint(callbacks.ModelCheckpoint):
         save_weights_only (bool): if True, then only the model's weights will be saved.
         mode (Mode): one of {'auto', 'min', 'max'}. For `val_acc`, this should be `max`,
             for `val_loss` this should be `min`, etc.
-        save_weights_only (bool): if True, then only the model's weights will be saved
         save_freq (Union[SaveStrategy, int]): `epoch` or integer. When using `'epoch'`,
             the callback saves the model after each epoch. When using an integer, the
             callback saves the model at end of this many batches.
