@@ -43,7 +43,7 @@ class Settings:
                     raise
 
     def set(self, section, key, value, globally=False, persist=False) -> None:
-        """Persists settings to disk if persist = True"""
+        """Persist settings to disk if persist = True"""
 
         def write_setting(settings, settings_path, persist):
             if not settings.has_section(section):
@@ -109,7 +109,7 @@ class Settings:
         config_dir = os.environ.get(
             env.CONFIG_DIR, os.path.join(os.path.expanduser("~"), ".config", "wandb")
         )
-        filesystem.mkdir_exists_ok(config_dir)
+        os.makedirs(config_dir, exist_ok=True)
         return os.path.join(config_dir, "settings")
 
     @staticmethod
