@@ -54,12 +54,10 @@ class _WBValueArtifactTarget:
 
 
 class WBValue:
-    """
-    Abstract parent class for things that can be logged by `wandb.log()` and
-    visualized by wandb.
+    """Typed objects that can be logged with `wandb.log()` and visualized by wandb.
 
-    The objects will be serialized as JSON and always have a _type attribute
-    that indicates how to interpret the other fields.
+    The objects will be serialized as JSON and always have a _type attribute that
+    indicates how to interpret the other fields.
     """
 
     # Class Attributes
@@ -76,11 +74,14 @@ class WBValue:
         self._artifact_target = None
 
     def to_json(self, run_or_artifact: Union["LocalRun", "LocalArtifact"]) -> dict:
-        """Serializes the object into a JSON blob, using a run or artifact to store additional data.
+        """Serialize the object into a JSON blob.
+
+        Uses current run or artifact to store additional data.
 
         Args:
-            run_or_artifact (wandb.Run | wandb.Artifact): the Run or Artifact for which this object should be generating
-            JSON for - this is useful to to store additional data if needed.
+            run_or_artifact (wandb.Run | wandb.Artifact): the Run or Artifact for which
+                this object should be generating JSON for - this is useful to to store
+                additional data if needed.
 
         Returns:
             dict: JSON representation
@@ -91,27 +92,29 @@ class WBValue:
     def from_json(
         cls: Type["WBValue"], json_obj: dict, source_artifact: "PublicArtifact"
     ) -> "WBValue":
-        """Deserialize a `json_obj` into it's class representation. If additional resources were stored in the
-        `run_or_artifact` artifact during the `to_json` call, then those resources are expected to be in
-        the `source_artifact`.
+        """Deserialize a `json_obj` into it's class representation.
+
+        If additional resources were stored in the `run_or_artifact` artifact during the
+        `to_json` call, then those resources should be in the `source_artifact`.
 
         Args:
-            json_obj (dict): A JSON dictionary to deserialize
-            source_artifact (wandb.Artifact): An artifact which will hold any additional resources which were stored
-            during the `to_json` function.
+            json_obj (dict): A JSON dictionary to deserialize source_artifact
+            (wandb.Artifact): An artifact which will hold any additional
+                resources which were stored during the `to_json` function.
         """
         raise NotImplementedError
 
     @classmethod
     def with_suffix(cls: Type["WBValue"], name: str, filetype: str = "json") -> str:
-        """Helper function to return the name with suffix added if not already
+        """Get the name with the appropriate suffix.
 
         Args:
             name (str): the name of the file
             filetype (str, optional): the filetype to use. Defaults to "json".
 
         Returns:
-            str: a filename which is suffixed with it's `_log_type` followed by the filetype
+            str: a filename which is suffixed with it's `_log_type` followed by the
+                filetype.
         """
         if cls._log_type is not None:
             suffix = cls._log_type + "." + filetype
@@ -125,16 +128,20 @@ class WBValue:
     def init_from_json(
         json_obj: dict, source_artifact: "PublicArtifact"
     ) -> Optional["WBValue"]:
-        """Looks through all subclasses and tries to match the json obj with the class which created it. It will then
-        call that subclass' `from_json` method. Importantly, this function will set the return object's `source_artifact`
-        attribute to the passed in source artifact. This is critical for artifact bookkeeping. If you choose to create
-        a wandb.Value via it's `from_json` method, make sure to properly set this `artifact_source` to avoid data duplication.
+        """Initialize a `WBValue` from a JSON blob based on the class that creatd it.
+
+        Looks through all subclasses and tries to match the json obj with the class
+        which created it. It will then call that subclass' `from_json` method.
+        Importantly, this function will set the return object's `source_artifact`
+        attribute to the passed in source artifact. This is critical for artifact
+        bookkeeping. If you choose to create a wandb.Value via it's `from_json` method,
+        make sure to properly set this `artifact_source` to avoid data duplication.
 
         Args:
-            json_obj (dict): A JSON dictionary to deserialize. It must contain a `_type` key. The value of
-            this key is used to lookup the correct subclass to use.
-            source_artifact (wandb.Artifact): An artifact which will hold any additional resources which were stored
-            during the `to_json` function.
+            json_obj (dict): A JSON dictionary to deserialize. It must contain a `_type`
+                key. This is used to lookup the correct subclass to use.
+            source_artifact (wandb.Artifact): An artifact which will hold any additional
+                resources which were stored during the `to_json` function.
 
         Returns:
             wandb.Value: a newly created instance of a subclass of wandb.Value
@@ -149,7 +156,7 @@ class WBValue:
 
     @staticmethod
     def type_mapping() -> "TypeMappingType":
-        """Returns a map from `_log_type` to subclass. Used to lookup correct types for deserialization.
+        """Return a map from `_log_type` to subclass. Used to lookup correct types for deserialization.
 
         Returns:
             dict: dictionary of str:class
@@ -175,7 +182,7 @@ class WBValue:
         return not self.__eq__(other)
 
     def to_data_array(self) -> List[Any]:
-        """Converts the object to a list of primitives representing the underlying data"""
+        """Convert the object to a list of primitives representing the underlying data."""
         raise NotImplementedError
 
     def _set_artifact_source(
