@@ -2,7 +2,6 @@ import collections
 import dataclasses
 import json
 import logging
-import multiprocessing as mp
 import pathlib
 import shutil
 import subprocess
@@ -92,9 +91,7 @@ class _Stats:
 
 
 class NeuronCoreStats:
-    """
-    AWS Trainium stats.
-    """
+    """AWS Trainium stats."""
 
     name: str = "trn.{key}"
     samples: "Deque[_Stats]"
@@ -124,7 +121,7 @@ class NeuronCoreStats:
             ) as process:
                 while not self.shutdown_event.is_set():
                     if process.stdout is None:
-                        time.sleep(0.1)
+                        self.shutdown_event.wait(0.1)
                         continue
 
                     raw_data = process.stdout.readline()
@@ -151,6 +148,15 @@ class NeuronCoreStats:
         self.samples: "Deque[_Stats]" = deque()
         self.shutdown_event = threading.Event()
 
+        self.neuron_monitor_thread: Optional[threading.Thread] = None
+
+    def setup(self) -> None:
+        """Start the neuron-monitor thread for collecting raw data."""
+        if self.neuron_monitor_thread is not None:
+            return
+
+        logger.debug("Starting neuron-monitor thread")
+        self.shutdown_event.clear()
         self.neuron_monitor_thread = threading.Thread(
             name="NeuronCoreMntr",
             target=self.neuron_monitor,
@@ -158,9 +164,20 @@ class NeuronCoreStats:
         )
         self.neuron_monitor_thread.start()
 
+    def teardown(self) -> None:
+        """Stop the neuron-monitor thread."""
+        logger.debug("Stopping neuron-monitor thread")
+        try:
+            self.shutdown_event.set()
+            assert self.neuron_monitor_thread is not None
+            self.neuron_monitor_thread.join()
+        except Exception as e:
+            logger.error("neuron-monitor thread failed to stop: %s" % e)
+        finally:
+            self.neuron_monitor_thread = None
+
     def _is_matching_entry(self, entry: dict) -> bool:
-        """
-        For now, only check if the pid in the entry matches the pid of the process.
+        """For now, only check if the pid in the entry matches the pid of the process.
 
         todo: add matching by neuron_runtime_tag
         """
@@ -218,9 +235,7 @@ class NeuronCoreStats:
 
     @staticmethod
     def flatten_stats(sample: _Stats) -> dict:
-        """
-        Flatten _Stats object into a flat dict of numbers.
-        """
+        """Flatten _Stats object into a flat dict of numbers."""
         flattened = {}
 
         def helper(key: str, value: Any) -> None:
@@ -272,7 +287,7 @@ class Trainium:
         self,
         interface: "Interface",
         settings: "SettingsStatic",
-        shutdown_event: mp.synchronize.Event,
+        shutdown_event: threading.Event,
     ) -> None:
         self.name = self.__class__.__name__.lower()
         self.metrics: List[Metric] = [
@@ -302,6 +317,7 @@ class Trainium:
         # on some systems that do not have the hardware
         try:
             # redirect stderr to null to avoid printing errors to the console
+            # todo: alternative: check /dev/neuron0 ? sysfs support coming soon in neuron tools
             output = subprocess.check_output(
                 NEURON_LS_COMMAND,
                 universal_newlines=True,
@@ -319,11 +335,6 @@ class Trainium:
 
     def finish(self) -> None:
         self.metrics_monitor.finish()
-        # stop the raw data acquisition threads
-        for metric in self.metrics:
-            if hasattr(metric, "shutdown_event"):
-                logger.debug("Stopping neuron-monitor thread")
-                metric.shutdown_event.set()
 
     def probe(self) -> dict:
         try:
