@@ -1,11 +1,11 @@
 import logging
-import multiprocessing as mp
 import queue
 import threading
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import TYPE_CHECKING, List, Optional
 
 from .assets.asset_registry import asset_registry
 from .assets.interfaces import Asset, Interface
+from .assets.open_metrics import OpenMetrics
 from .system_info import SystemInfo
 
 if TYPE_CHECKING:
@@ -43,9 +43,10 @@ class SystemMonitor:
         settings: "SettingsStatic",
         interface: "Interface",
     ) -> None:
+        self._shutdown_event: threading.Event = threading.Event()
+        self._process: Optional[threading.Thread] = None
 
-        self._shutdown_event: mp.synchronize.Event = mp.Event()
-        self._process: Optional[Union[mp.Process, threading.Thread]] = None
+        self.settings = settings
 
         # settings._stats_join_assets controls whether we should join stats from different assets
         # before publishing them to the backend. If set to False, we will publish stats from each
@@ -59,14 +60,16 @@ class SystemMonitor:
         sampling_interval: float = float(
             max(
                 0.1,
-                settings._stats_sample_rate_seconds,
+                self.settings._stats_sample_rate_seconds,
             )
         )  # seconds
         # The number of samples to aggregate (e.g. average or compute max/min etc.)
         # before publishing; defaults to 15; valid range: [1:30]
-        samples_to_aggregate: int = min(30, max(1, settings._stats_samples_to_average))
+        samples_to_aggregate: int = min(
+            30, max(1, self.settings._stats_samples_to_average)
+        )
         self.publishing_interval: float = sampling_interval * samples_to_aggregate
-        self.join_assets: bool = settings._stats_join_assets
+        self.join_assets: bool = self.settings._stats_join_assets
 
         self.backend_interface = interface
         self.asset_interface: Optional[AssetInterface] = (
@@ -74,21 +77,47 @@ class SystemMonitor:
         )
 
         # hardware assets
-        self.assets: List["Asset"] = []
-        for asset_class in asset_registry:
-            self.assets.append(
-                asset_class(
-                    interface=self.asset_interface or self.backend_interface,
-                    settings=settings,
-                    shutdown_event=self._shutdown_event,
-                )
-            )
+        self.assets: List["Asset"] = self._get_assets()
+
+        # OpenMetrics/Prometheus-compatible endpoints
+        self.assets.extend(self._get_open_metrics_assets())
 
         # static system info, both hardware and software
         self.system_info: SystemInfo = SystemInfo(
-            settings=settings, interface=interface
+            settings=self.settings, interface=interface
         )
 
+    def _get_assets(self) -> List["Asset"]:
+        return [
+            asset_class(
+                interface=self.asset_interface or self.backend_interface,
+                settings=self.settings,
+                shutdown_event=self._shutdown_event,
+            )
+            for asset_class in asset_registry
+        ]
+
+    def _get_open_metrics_assets(self) -> List["Asset"]:
+        open_metrics_endpoints = self.settings._stats_open_metrics_endpoints
+        if not open_metrics_endpoints:
+            return []
+
+        assets: List[Asset] = []
+        for name, endpoint in open_metrics_endpoints.items():
+            if not OpenMetrics.is_available(url=endpoint):
+                continue
+            logger.debug(f"Monitoring OpenMetrics endpoint: {endpoint}")
+            open_metrics = OpenMetrics(
+                interface=self.asset_interface or self.backend_interface,
+                settings=self.settings,
+                shutdown_event=self._shutdown_event,
+                name=name,
+                url=endpoint,
+            )
+            assets.append(open_metrics)  # type: ignore
+
+        return assets
+
     def aggregate_and_publish_asset_metrics(self) -> None:
         if self.asset_interface is None:
             return None
@@ -147,13 +176,13 @@ class SystemMonitor:
 
     def start(self) -> None:
         self._shutdown_event.clear()
-        if self._process is None:
-            logger.info("Starting system monitor")
-            # self._process = mp.Process(target=self._start, name="SystemMonitor")
-            self._process = threading.Thread(
-                target=self._start, daemon=True, name="SystemMonitor"
-            )
-            self._process.start()
+        if self._process is not None:
+            return None
+        logger.info("Starting system monitor")
+        self._process = threading.Thread(
+            target=self._start, daemon=True, name="SystemMonitor"
+        )
+        self._process.start()
 
     def finish(self) -> None:
         if self._process is None:
