@@ -4,7 +4,6 @@ from typing import Any, Dict, List, Optional
 import wandb
 import wandb.apis.public as public
 from wandb.apis.internal import Api
-from wandb.errors import LaunchError
 from wandb.sdk.launch._project_spec import (
     compute_command_args,
     create_project_from_spec,
@@ -13,6 +12,7 @@ from wandb.sdk.launch.builder.build import build_image_from_project
 from wandb.sdk.launch.utils import (
     LAUNCH_DEFAULT_PROJECT,
     LOG_PREFIX,
+    LaunchError,
     construct_launch_spec,
     validate_launch_spec_source,
 )
@@ -44,7 +44,6 @@ def launch_add(
     params: Optional[Dict[str, Any]] = None,
     project_queue: Optional[str] = None,
     resource_args: Optional[Dict[str, Any]] = None,
-    cuda: Optional[bool] = None,
     run_id: Optional[str] = None,
     build: Optional[bool] = False,
     repository: Optional[str] = None,
@@ -69,7 +68,6 @@ def launch_add(
         the parameters used to run the original run.
     resource_args: Resource related arguments for launching runs onto a remote backend.
         Will be stored on the constructed launch config under ``resource_args``.
-    cuda: Whether to build a CUDA-enabled docker image or not
     run_id: optional string indicating the id of the launched run
     build: optional flag defaulting to false, requires queue to be set
         if build, an image is created, creates a job artifact, pushes a reference
@@ -116,7 +114,6 @@ def launch_add(
         params,
         project_queue,
         resource_args,
-        cuda,
         run_id=run_id,
         build=build,
         repository=repository,
@@ -139,7 +136,6 @@ def _launch_add(
     params: Optional[Dict[str, Any]],
     project_queue: Optional[str],
     resource_args: Optional[Dict[str, Any]] = None,
-    cuda: Optional[bool] = None,
     run_id: Optional[str] = None,
     build: Optional[bool] = False,
     repository: Optional[str] = None,
@@ -158,7 +154,6 @@ def _launch_add(
         params,
         resource_args,
         config,
-        cuda,
         run_id,
         repository,
     )
@@ -174,7 +169,7 @@ def _launch_add(
             launch_spec["job"] = None
 
         launch_project = create_project_from_spec(launch_spec, api)
-        docker_image_uri = build_image_from_project(launch_project, api, config)
+        docker_image_uri = build_image_from_project(launch_project, api, config or {})
         run = wandb.run or wandb.init(
             project=launch_spec["project"],
             entity=launch_spec["entity"],
@@ -207,7 +202,10 @@ def _launch_add(
         if updated_spec.get("resource"):
             launch_spec["resource"] = updated_spec.get("resource")
 
-    wandb.termlog(f"{LOG_PREFIX}Added run to queue {project_queue}/{queue_name}.")
+    if project_queue == LAUNCH_DEFAULT_PROJECT:
+        wandb.termlog(f"{LOG_PREFIX}Added run to queue {queue_name}.")
+    else:
+        wandb.termlog(f"{LOG_PREFIX}Added run to queue {project_queue}/{queue_name}.")
     wandb.termlog(f"{LOG_PREFIX}Launch spec:\n{pprint.pformat(launch_spec)}\n")
     public_api = public.Api()
     container_job = False
