@@ -1,6 +1,4 @@
-"""
-apikey util.
-"""
+"""apikey util."""
 
 import os
 import stat
@@ -151,7 +149,7 @@ def prompt_api_key(  # noqa: C901
 
 
 def write_netrc(host, entity, key):
-    """Add our host and key to .netrc"""
+    """Add our host and key to .netrc."""
     key_prefix, key_suffix = key.split("-", 1) if "-" in key else ("", key)
     if len(key_suffix) != 40:
         wandb.termerror(
