@@ -263,7 +263,7 @@ class PrinterJupyter(_Printer):
         return f'<strong style="color:#cdcd00">{text}</strong>'
 
     def link(self, link: str, text: Optional[str] = None) -> str:
-        return f'<a href="{link}" target="_blank">{text or link}</a>'
+        return f'<a href={link!r} target="_blank">{text or link}</a>'
 
     def emoji(self, name: str) -> str:
         return ""
@@ -297,7 +297,10 @@ class PrinterJupyter(_Printer):
         return f'{ipython.TABLE_STYLES}<div class="wandb-row">{row}</div>'
 
 
-def get_printer(_jupyter: Optional[bool] = None) -> Union[PrinterTerm, PrinterJupyter]:
+Printer = Union[PrinterTerm, PrinterJupyter]
+
+
+def get_printer(_jupyter: Optional[bool] = None) -> Printer:
     if _jupyter and ipython.in_jupyter():
         return PrinterJupyter()
     return PrinterTerm()
