@@ -104,9 +104,7 @@ def _get_char(code):
 
 
 class Char:
-    """
-    Class encapsulating a single character, its foreground, background and style attributes
-    """
+    """Class encapsulating a single character, its foreground, background and style attributes."""
 
     __slots__ = (
         "data",
@@ -174,17 +172,17 @@ _defchar = Char()
 
 
 class Cursor:
-    """
-    2D cursor
+    """A 2D cursor.
+
+    Attributes:
+        x: x-coordinate.
+        y: y-coordinate.
+        char: the character to inherit colors and styles from.
     """
 
     __slots__ = ("x", "y", "char")
 
     def __init__(self, x=0, y=0, char=None):
-        """
-        x, y - 2D coordinates
-        char - Next character to be written will inherit colors and styles from this character
-        """
         if char is None:
             char = Char()
         self.x = x
@@ -193,8 +191,9 @@ class Cursor:
 
 
 class TerminalEmulator:
-    """
-    An FSM emulating a terminal. Characters are stored in a 2D matrix (buffer) indexed by the cursor.
+    """An FSM emulating a terminal.
+
+    Characters are stored in a 2D matrix (buffer) indexed by the cursor.
     """
 
     _MAX_LINES = 100
@@ -488,8 +487,7 @@ _MIN_CALLBACK_INTERVAL = 2  # seconds
 
 class RedirectBase:
     def __init__(self, src, cbs=()):
-        """
-        # Arguments
+        """# Arguments.
 
         `src`: Source stream to be redirected. "stdout" or "stderr".
         `cbs`: tuple/list of callbacks. Each callback should take exactly 1 argument (bytes).
@@ -527,9 +525,7 @@ class RedirectBase:
 
 
 class StreamWrapper(RedirectBase):
-    """
-    Patches the write method of current sys.stdout/sys.stderr
-    """
+    """Patches the write method of current sys.stdout/sys.stderr."""
 
     def __init__(self, src, cbs=()):
         super().__init__(src=src, cbs=cbs)
@@ -620,8 +616,7 @@ class StreamWrapper(RedirectBase):
 
 
 class StreamRawWrapper(RedirectBase):
-    """
-    Patches the write method of current sys.stdout/sys.stderr
+    """Patches the write method of current sys.stdout/sys.stderr.
 
     Captures data in a raw form rather than using the emulator
     """
@@ -697,7 +692,7 @@ class _WindowSizeChangeHandler:
             win_size = fcntl.ioctl(0, termios.TIOCGWINSZ, "\0" * 8)
             rows, cols, xpix, ypix = struct.unpack("HHHH", win_size)
         # Note: IOError not subclass of OSError in python 2.x
-        except OSError:  # eg. in MPI we can't do this. # noqa
+        except OSError:  # eg. in MPI we can't do this.
             return
         if cols == 0:
             return
@@ -710,9 +705,7 @@ _WSCH = _WindowSizeChangeHandler()
 
 
 class Redirect(RedirectBase):
-    """
-    Redirects low level file descriptors.
-    """
+    """Redirect low level file descriptors."""
 
     def __init__(self, src, cbs=()):
         super().__init__(src=src, cbs=cbs)
