@@ -12,9 +12,10 @@ from typing import Any, Awaitable, Callable, Generic, Optional, Tuple, Type, Typ
 from requests import HTTPError
 
 import wandb
-from wandb.errors import ContextCancelledError
 from wandb.util import CheckRetryFnType
 
+from .mailbox import ContextCancelledError
+
 logger = logging.getLogger(__name__)
 
 
@@ -26,7 +27,7 @@ SLEEP_ASYNC_FN = asyncio.sleep
 
 
 class TransientError(Exception):
-    """Exception type designated for errors that may only be temporary
+    """Exception type designated for errors that may only be temporary.
 
     Can have its own message and/or wrap another exception.
     """
@@ -43,7 +44,7 @@ _R = TypeVar("_R")
 
 
 class Retry(Generic[_R]):
-    """Creates a retryable version of a function.
+    """Create a retryable version of a function.
 
     Calling this will call the passed function, retrying if any exceptions in
     retryable_exceptions are caught, with exponential backoff.
@@ -98,7 +99,6 @@ class Retry(Generic[_R]):
            sleep_base (kwarg): amount of time to sleep upon first failure, all other sleeps
                are derived from this one.
         """
-
         retry_timedelta = kwargs.pop("retry_timedelta", self._retry_timedelta)
         if retry_timedelta is None:
             retry_timedelta = datetime.timedelta(days=365)
@@ -279,7 +279,6 @@ async def retry_async(
 
     Each time `fn` fails, `on_exc` is called with the exception.
     """
-
     while True:
         try:
             return await fn(*args, **kwargs)
