@@ -12,12 +12,9 @@ import tempfile
 import time
 from typing import TYPE_CHECKING, Any, Dict, Optional
 
-from ...errors import (
-    ServiceStartPortError,
-    ServiceStartProcessError,
-    ServiceStartTimeoutError,
-)
-from ...util import sentry_reraise, sentry_set_scope
+from wandb import _sentry
+from wandb.errors import Error
+
 from . import _startup_debug, port_file
 from .service_base import ServiceInterface
 from .service_sock import ServiceSockInterface
@@ -26,6 +23,24 @@ if TYPE_CHECKING:
     from wandb.sdk.wandb_settings import Settings
 
 
+class ServiceStartProcessError(Error):
+    """Raised when a known error occurs when launching wandb service."""
+
+    pass
+
+
+class ServiceStartTimeoutError(Error):
+    """Raised when service start times out."""
+
+    pass
+
+
+class ServiceStartPortError(Error):
+    """Raised when service start fails to find a port."""
+
+    pass
+
+
 class _Service:
     _settings: "Settings"
     _grpc_port: Optional[int]
@@ -46,7 +61,7 @@ class _Service:
         self._internal_proc = None
         self._startup_debug_enabled = _startup_debug.is_enabled()
 
-        sentry_set_scope(process_context="service")
+        _sentry.configure_scope(process_context="service")
 
         # Temporary setting to allow use of grpc so that we can keep
         # that code from rotting during the transition
@@ -69,8 +84,7 @@ class _Service:
     def _wait_for_ports(
         self, fname: str, proc: Optional[subprocess.Popen] = None
     ) -> None:
-        """
-        Wait for the service to write the port file and then read it.
+        """Wait for the service to write the port file and then read it.
 
         Args:
             fname: The path to the port file.
@@ -87,14 +101,24 @@ class _Service:
             if proc and proc.poll():
                 # process finished
                 # define these variables for sentry context grab:
-                command = proc.args  # noqa: F841
-                sys_executable = sys.executable  # noqa: F841
-                which_python = shutil.which("python3")  # noqa: F841
+                # command = proc.args
+                # sys_executable = sys.executable
+                # which_python = shutil.which("python3")
+                # proc_out = proc.stdout.read()
+                # proc_err = proc.stderr.read()
+                context = dict(
+                    command=proc.args,
+                    sys_executable=sys.executable,
+                    which_python=shutil.which("python3"),
+                    proc_out=proc.stdout.read() if proc.stdout else "",
+                    proc_err=proc.stderr.read() if proc.stderr else "",
+                )
                 raise ServiceStartProcessError(
                     f"The wandb service process exited with {proc.returncode}. "
                     "Ensure that `sys.executable` is a valid python interpreter. "
                     "You can override it with the `_executable` setting "
-                    "or with the `WANDB__EXECUTABLE` environment variable."
+                    "or with the `WANDB__EXECUTABLE` environment variable.",
+                    context=context,
                 )
             if not os.path.isfile(fname):
                 time.sleep(0.2)
@@ -122,7 +146,6 @@ class _Service:
 
     def _launch_server(self) -> None:
         """Launch server and set ports."""
-
         # References for starting processes
         # - https://github.com/wandb/wandb/blob/archive/old-cli/wandb/__init__.py
         # - https://stackoverflow.com/questions/1196074/how-to-start-a-background-process-in-python
@@ -167,7 +190,7 @@ class _Service:
             try:
                 self._wait_for_ports(fname, proc=internal_proc)
             except Exception as e:
-                sentry_reraise(e, delay=True)
+                _sentry.reraise(e)
             self._startup_debug_print("wait_ports_done")
             self._internal_proc = internal_proc
         self._startup_debug_print("launch_done")
