@@ -1,9 +1,6 @@
-#
 import abc
 import typing as t
 
-import six
-
 from .interface.summary_record import SummaryItem, SummaryRecord
 
 
@@ -14,10 +11,11 @@ def _get_dict(d):
     return vars(d)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SummaryDict(object):
-    """dict-like which wraps all nested dictionraries in a SummarySubDict,
-     and triggers self._root._callback on property changes."""
+class SummaryDict(metaclass=abc.ABCMeta):
+    """dict-like wrapper for the nested dictionaries in a SummarySubDict.
+
+    Triggers self._root._callback on property changes.
+    """
 
     @abc.abstractmethod
     def _as_dict(self):
@@ -67,7 +65,7 @@ class SummaryDict(object):
     def update(self, d: t.Dict):
         # import ipdb; ipdb.set_trace()
         record = SummaryRecord()
-        for key, value in six.iteritems(d):
+        for key, value in d.items():
             item = SummaryItem()
             item.key = (key,)
             item.value = value
@@ -77,8 +75,7 @@ class SummaryDict(object):
 
 
 class Summary(SummaryDict):
-    """
-    Tracks single values for each metric for each run.
+    """Track single values for each metric for each run.
 
     By default, a metric's summary is the last value of its History.
 
@@ -103,10 +100,10 @@ class Summary(SummaryDict):
 
         best_accuracy = 0
         for epoch in range(1, args.epochs + 1):
-        test_loss, test_accuracy = test()
-        if (test_accuracy > best_accuracy):
-            wandb.run.summary["best_accuracy"] = test_accuracy
-            best_accuracy = test_accuracy
+            test_loss, test_accuracy = test()
+            if test_accuracy > best_accuracy:
+                wandb.run.summary["best_accuracy"] = test_accuracy
+                best_accuracy = test_accuracy
         ```
     """
 
@@ -114,7 +111,7 @@ class Summary(SummaryDict):
     _get_current_summary_callback: t.Callable
 
     def __init__(self, get_current_summary_callback: t.Callable):
-        super(Summary, self).__init__()
+        super().__init__()
         object.__setattr__(self, "_update_callback", None)
         object.__setattr__(
             self, "_get_current_summary_callback", get_current_summary_callback
@@ -132,8 +129,10 @@ class Summary(SummaryDict):
 
 
 class SummarySubDict(SummaryDict):
-    """Non-root node of the summary data structure. Contains a path to itself
-    from the root."""
+    """Non-root node of the summary data structure.
+
+    Contains a path to itself from the root.
+    """
 
     _items: t.Dict
     _parent: SummaryDict
