@@ -2,13 +2,11 @@ from warnings import simplefilter
 
 import numpy as np
 import sklearn
-from sklearn import naive_bayes
+from sklearn import model_selection, naive_bayes
 from sklearn.calibration import CalibratedClassifierCV
 from sklearn.linear_model import LogisticRegression
-from sklearn import model_selection
 
 import wandb
-
 from wandb.sklearn import utils
 
 # ignore all future warnings
