@@ -1,4 +1,4 @@
-"""Creates and logs charts introspecting models built with scikit-learn to W&B."""
+"""Create and logs charts introspecting models built with scikit-learn to W&B."""
 from .classifier import calibration_curve as plot_calibration_curve
 from .classifier import class_proportions as plot_class_proportions
 from .classifier import classifier as plot_classifier
