@@ -26,7 +26,7 @@ import urllib
 from datetime import date, datetime, timedelta
 from importlib import import_module
 from sys import getsizeof
-from types import ModuleType, TracebackType
+from types import ModuleType
 from typing import (
     IO,
     TYPE_CHECKING,
@@ -43,18 +43,15 @@ from typing import (
     Set,
     TextIO,
     Tuple,
-    Type,
     Union,
 )
-from urllib.parse import quote
 
 import requests
-import sentry_sdk  # type: ignore
 import yaml
 
 import wandb
-from wandb.env import SENTRY_DSN, error_reporting_enabled, get_app_url
-from wandb.errors import CommError, UsageError, term
+from wandb.env import get_app_url
+from wandb.errors import AuthenticationError, CommError, UsageError, term
 from wandb.sdk.lib import filesystem, runid
 
 if TYPE_CHECKING:
@@ -133,24 +130,6 @@ def get_platform_name() -> str:
         return PLATFORM_UNKNOWN
 
 
-# TODO(sentry): This code needs to be moved, sentry shouldn't be initialized as a
-#  side effect of loading a module.
-sentry_client: Optional["sentry_sdk.client.Client"] = None
-sentry_hub: Optional["sentry_sdk.hub.Hub"] = None
-sentry_default_dsn = (
-    "https://a2f1d701163c42b097b9588e56b1c37e@o151352.ingest.sentry.io/5288891"
-)
-if error_reporting_enabled():
-    sentry_dsn = os.environ.get(SENTRY_DSN, sentry_default_dsn)
-    sentry_client = sentry_sdk.Client(
-        dsn=sentry_dsn,
-        default_integrations=False,
-        environment=SENTRY_ENV,
-        release=wandb.__version__,
-    )
-
-    sentry_hub = sentry_sdk.Hub(sentry_client)
-
 POW_10_BYTES = [
     ("B", 10**0),
     ("KB", 10**3),
@@ -172,133 +151,20 @@ POW_2_BYTES = [
 ]
 
 
-def sentry_message(message: str) -> None:
-    if error_reporting_enabled():
-        sentry_hub.capture_message(message)  # type: ignore
-    return None
-
-
-def sentry_exc(
-    exc: Union[
-        str,
-        BaseException,
-        Tuple[
-            Optional[Type[BaseException]],
-            Optional[BaseException],
-            Optional[TracebackType],
-        ],
-        None,
-    ],
-    delay: bool = False,
-) -> None:
-    if error_reporting_enabled():
-        if isinstance(exc, str):
-            sentry_hub.capture_exception(Exception(exc))  # type: ignore
-        else:
-            sentry_hub.capture_exception(exc)  # type: ignore
-    if delay:
-        time.sleep(2)
-    return None
-
-
-def sentry_reraise(exc: Any, delay: bool = False) -> None:
-    """Re-raise an exception after logging it to Sentry
-
-    Use this for top-level exceptions when you want the user to see the traceback.
-
-    Must be called from within an exception handler.
-    """
-    sentry_exc(exc, delay=delay)
-    # this will messily add this "reraise" function to the stack trace,
-    # but hopefully it's not too bad
-    raise exc.with_traceback(sys.exc_info()[2])
-
-
-def sentry_set_scope(
-    settings_dict: Optional[
-        Union[
-            "wandb.sdk.wandb_settings.Settings",
-            "wandb.sdk.internal.settings_static.SettingsStatic",
-        ]
-    ] = None,
-    process_context: Optional[str] = None,
-) -> None:
-    if not error_reporting_enabled():
-        return None
-
-    # Tags come from two places: settings and args passed into this func.
-    args = dict(locals())
-    del args["settings_dict"]
-
-    settings_tags = [
-        "entity",
-        "project",
-        "run_id",
-        "run_url",
-        "sweep_url",
-        "sweep_id",
-        "deployment",
-        "_require_service",
-    ]
-
-    s = settings_dict
-
-    # convenience function for getting attr from settings
-    def get(key: str) -> Any:
-        return getattr(s, key, None)
-
-    with sentry_hub.configure_scope() as scope:  # type: ignore
-        scope.set_tag("platform", get_platform_name())
-
-        # apply settings tags
-        if s is not None:
-            for tag in settings_tags:
-                val = get(tag)
-                if val not in [None, ""]:
-                    scope.set_tag(tag, val)
-
-            python_runtime = (
-                "colab"
-                if get("_colab")
-                else ("jupyter" if get("_jupyter") else "python")
-            )
-            scope.set_tag("python_runtime", python_runtime)
-
-            # Hack for constructing run_url and sweep_url given run_id and sweep_id
-            required = ["entity", "project", "base_url"]
-            params = {key: get(key) for key in required}
-            if all(params.values()):
-                # here we're guaranteed that entity, project, base_url all have valid values
-                app_url = wandb.util.app_url(params["base_url"])
-                e, p = (quote(params[k]) for k in ["entity", "project"])
-
-                # TODO: the settings object will be updated to contain run_url and sweep_url
-                # This is done by passing a settings_map in the run_start protocol buffer message
-                for word in ["run", "sweep"]:
-                    _url, _id = f"{word}_url", f"{word}_id"
-                    if not get(_url) and get(_id):
-                        scope.set_tag(_url, f"{app_url}/{e}/{p}/{word}s/{get(_id)}")
-
-            if hasattr(s, "email"):
-                scope.user = {"email": s.email}
-
-        # apply directly passed-in tags
-        for tag, value in args.items():
-            if value is not None and value != "":
-                scope.set_tag(tag, value)
-
-    # Track session so we can get metrics about error free rate
-    if sentry_hub:
-        sentry_hub.start_session()
-
-
 def vendor_setup() -> Callable:
-    """This enables us to use the vendor directory for packages we don't depend on
-    Returns a function to call after imports are complete. Make sure to call this
-    function or you will modify the user's path which is never good. The pattern should be:
+    """Create a function that restores user paths after vendor imports.
+
+    This enables us to use the vendor directory for packages we don't depend on. Call
+    the returned function after imports are complete. If you don't you may modify the
+    user's path which is never good.
+
+    Usage:
+
+    ```python
     reset_path = vendor_setup()
     # do any vendor imports...
     reset_path()
+    ```
     """
     original_path = [directory for directory in sys.path]
 
@@ -329,8 +195,7 @@ def vendor_import(name: str) -> Any:
 
 
 def import_module_lazy(name: str) -> Any:
-    """
-    Import a module lazily, only when it is used.
+    """Import a module lazily, only when it is used.
 
     :param (str) name: Dot-separated module path. E.g., 'scipy.stats'.
     """
@@ -356,8 +221,7 @@ def get_module(
     required: Optional[Union[str, bool]] = None,
     lazy: bool = True,
 ) -> Any:
-    """
-    Return module or None. Absolute import is required.
+    """Return module or None. Absolute import is required.
 
     :param (str) name: Dot-separated module path. E.g., 'scipy.stats'.
     :param (str) required: A string to raise a ValueError if missing
@@ -390,7 +254,7 @@ VALUE_BYTES_LIMIT = 100000
 
 
 def app_url(api_url: str) -> str:
-    """Returns the frontend app url without a trailing slash."""
+    """Return the frontend app url without a trailing slash."""
     # TODO: move me to settings
     app_url = get_app_url()
     if app_url is not None:
@@ -409,8 +273,9 @@ def app_url(api_url: str) -> str:
 
 
 def get_full_typename(o: Any) -> Any:
-    """We determine types based on type names so we don't have to import
-    (and therefore depend on) PyTorch, TensorFlow, etc.
+    """Determine types based on type names.
+
+    Avoids needing to to import (and therefore depend on) PyTorch, TensorFlow, etc.
     """
     instance_name = o.__class__.__module__ + "." + o.__class__.__name__
     if instance_name in ["builtins.module", "__builtin__.module"]:
@@ -435,8 +300,8 @@ def is_uri(string: str) -> bool:
 
 
 def local_file_uri_to_path(uri: str) -> str:
-    """
-    Convert URI to local filesystem path.
+    """Convert URI to local filesystem path.
+
     No-op if the uri does not have the expected scheme.
     """
     path = urllib.parse.urlparse(uri).path if uri.startswith("file:") else uri
@@ -444,8 +309,10 @@ def local_file_uri_to_path(uri: str) -> str:
 
 
 def get_local_path_or_none(path_or_uri: str) -> Optional[str]:
-    """Check if the argument is a local path (no scheme or file:///) and return local path if true,
-    None otherwise.
+    """Return path if local, None otherwise.
+
+    Return None if the argument is a local path (not a scheme or file:///). Otherwise
+    return `path_or_uri`.
     """
     parsed_uri = urllib.parse.urlparse(path_or_uri)
     if (
@@ -581,8 +448,10 @@ def is_pandas_data_frame(obj: Any) -> bool:
 
 
 def ensure_matplotlib_figure(obj: Any) -> Any:
-    """Extract the current figure from a matplotlib object or return the object if it's a figure.
-    raises ValueError if the object can't be converted.
+    """Extract the current figure from a matplotlib object.
+
+    Return the object itself if it's a figure.
+    Raises ValueError if the object can't be converted.
     """
     import matplotlib  # type: ignore
     from matplotlib.figure import Figure  # type: ignore
@@ -593,6 +462,7 @@ def ensure_matplotlib_figure(obj: Any) -> Any:
 
     def is_frame_like(self: Any) -> bool:
         """Return True if directly on axes frame.
+
         This is useful for determining if a spine is the edge of an
         old style MPL plot. If so, this function will return True.
         """
@@ -671,10 +541,10 @@ def _find_all_matching_keys(
        match_fn: The function to determine if the key is a match.
        visited: Keep track of visited nodes so we dont recurse forever.
        key_path: Keep track of all the keys to get to the current node.
+
     Yields:
        (key_path, key): The location where the key was found, and the key
     """
-
     if visited is None:
         visited = set()
     me = id(d)
@@ -706,8 +576,8 @@ def _sanitize_numpy_keys(d: Dict) -> Tuple[Dict, bool]:
 
 def json_friendly(  # noqa: C901
     obj: Any,
-) -> Union[Tuple[Any, bool], Tuple[Union[None, str, float], bool]]:  # noqa: C901
-    """Convert an object into something that's more becoming of JSON"""
+) -> Union[Tuple[Any, bool], Tuple[Union[None, str, float], bool]]:
+    """Convert an object into something that's more becoming of JSON."""
     converted = True
     typename = get_full_typename(obj)
 
@@ -770,7 +640,7 @@ def json_friendly(  # noqa: C901
 
 
 def json_friendly_val(val: Any) -> Any:
-    """Make any value (including dict, slice, sequence, etc) JSON friendly"""
+    """Make any value (including dict, slice, sequence, etc) JSON friendly."""
     converted: Union[dict, list]
     if isinstance(val, dict):
         converted = {}
@@ -844,7 +714,7 @@ def maybe_compress_summary(obj: Any, h5_typename: str) -> Tuple[Any, bool]:
 
 
 def launch_browser(attempt_launch_browser: bool = True) -> bool:
-    """Decide if we should launch a browser"""
+    """Decide if we should launch a browser."""
     _display_variables = ["DISPLAY", "WAYLAND_DISPLAY", "MIR_SOCKET"]
     _webbrowser_names_blocklist = ["www-browser", "lynx", "links", "elinks", "w3m"]
 
@@ -873,7 +743,7 @@ def generate_id(length: int = 8) -> str:
 
 
 def parse_tfjob_config() -> Any:
-    """Attempts to parse TFJob config, returning False if it can't find it"""
+    """Attempt to parse TFJob config, returning False if it can't find it."""
     if os.getenv("TF_CONFIG"):
         try:
             return json.loads(os.environ["TF_CONFIG"])
@@ -910,7 +780,9 @@ class WandBJSONEncoderOld(json.JSONEncoder):
 
 class WandBHistoryJSONEncoder(json.JSONEncoder):
     """A JSON Encoder that handles some extra types.
-    This encoder turns numpy like objects with a size > 32 into histograms"""
+
+    This encoder turns numpy like objects with a size > 32 into histograms.
+    """
 
     def default(self, obj: Any) -> Any:
         obj, converted = json_friendly(obj)
@@ -922,7 +794,9 @@ class WandBHistoryJSONEncoder(json.JSONEncoder):
 
 class JSONEncoderUncompressed(json.JSONEncoder):
     """A JSON Encoder that handles some extra types.
-    This encoder turns numpy like objects with a size > 32 into histograms"""
+
+    This encoder turns numpy like objects with a size > 32 into histograms.
+    """
 
     def default(self, obj: Any) -> Any:
         if is_numpy_array(obj):
@@ -949,7 +823,7 @@ def json_dump_uncompressed(obj: Any, fp: IO[str], **kwargs: Any) -> None:
 
 
 def json_dumps_safer_history(obj: Any, **kwargs: Any) -> str:
-    """Convert obj to json, with some extra encodable types, including histograms"""
+    """Convert obj to json, with some extra encodable types, including histograms."""
     return json.dumps(obj, cls=WandBHistoryJSONEncoder, **kwargs)
 
 
@@ -1006,11 +880,21 @@ def no_retry_auth(e: Any) -> bool:
         return True
     # Crash w/message on forbidden/unauthorized errors.
     if e.response.status_code == 401:
-        raise CommError("Invalid or missing api_key. Run `wandb login`")
+        raise AuthenticationError(
+            "The API key is either invalid or missing, or the host is incorrect. "
+            "To resolve this issue, you may try running the 'wandb login --host [hostname]' command. "
+            "The host defaults to 'https://api.wandb.ai' if not specified. "
+            f"(Error {e.response.status_code}: {e.response.reason})"
+        )
     elif wandb.run:
         raise CommError(f"Permission denied to access {wandb.run.path}")
     else:
-        raise CommError("Permission denied, ask the project owner to grant you access")
+        raise CommError(
+            "It appears that you do not have permission to access the requested resource. "
+            "Please reach out to the project owner to grant you access. "
+            "If you have the correct permissions, verify that there are no issues with your networking setup."
+            f"(Error {e.response.status_code}: {e.response.reason})"
+        )
 
 
 def check_retry_conflict(e: Any) -> Optional[bool]:
@@ -1078,6 +962,7 @@ def find_runner(program: str) -> Union[None, list, List[str]]:
 
     Arguments:
         program: The string name of the program to try to run.
+
     Returns:
         commandline list of strings to run the program (eg. with subprocess.call()) or None
     """
@@ -1096,7 +981,7 @@ def find_runner(program: str) -> Union[None, list, List[str]]:
 
 
 def downsample(values: Sequence, target_length: int) -> list:
-    """Downsamples 1d values to target_length, including start and end.
+    """Downsample 1d values to target_length, including start and end.
 
     Algorithm just rounds index down.
 
@@ -1131,7 +1016,7 @@ def get_log_file_path() -> str:
 
 
 def docker_image_regex(image: str) -> Any:
-    """regex for valid docker image names"""
+    """Regex match for valid docker image names."""
     if image:
         return re.match(
             r"^(?:(?=[^:\/]{1,253})(?!-)[a-zA-Z0-9-]{1,63}(?<!-)(?:\.(?!-)[a-zA-Z0-9-]{1,63}(?<!-))*(?::[0-9]{1,5})?/)?((?![._-])(?:[a-z0-9._-]*)(?<![._-])(?:/(?![._-])[a-z0-9._-]*(?<![._-]))*)(?::(?![.-])[a-zA-Z0-9_.-]{1,128})?$",
@@ -1141,9 +1026,11 @@ def docker_image_regex(image: str) -> Any:
 
 
 def image_from_docker_args(args: List[str]) -> Optional[str]:
-    """This scans docker run args and attempts to find the most likely docker image argument.
-    If excludes any argments that start with a dash, and the argument after it if it isn't a boolean
-    switch.  This can be improved, we currently fallback gracefully when this fails.
+    """Scan docker run args and attempt to find the most likely docker image argument.
+
+    It excludes any arguments that start with a dash, and the argument after it if it
+    isn't a boolean switch. This can be improved, we currently fallback gracefully when
+    this fails.
     """
     bool_args = [
         "-t",
@@ -1196,12 +1083,12 @@ def load_yaml(file: Any) -> Any:
 
 
 def image_id_from_k8s() -> Optional[str]:
-    """Pings the k8s metadata service for the image id.  Specify the
-    KUBERNETES_NAMESPACE environment variable if your pods are not in
-    the default namespace:
+    """Ping the k8s metadata service for the image id.
 
-    - name: KUBERNETES_NAMESPACE
-      valueFrom:
+    Specify the KUBERNETES_NAMESPACE environment variable if your pods are not in the
+    default namespace:
+
+    - name: KUBERNETES_NAMESPACE valueFrom:
         fieldRef:
           fieldPath: metadata.namespace
     """
@@ -1233,13 +1120,16 @@ def image_id_from_k8s() -> Optional[str]:
     return None
 
 
-def async_call(target: Callable, timeout: Optional[int] = None) -> Callable:
-    """Accepts a method and optional timeout.
-    Returns a new method that will call the original with any args, waiting for upto timeout seconds.
-    This new method blocks on the original and returns the result or None
-    if timeout was reached, along with the thread.
-    You can check thread.is_alive() to determine if a timeout was reached.
-    If an exception is thrown in the thread, we reraise it.
+def async_call(
+    target: Callable, timeout: Optional[Union[int, float]] = None
+) -> Callable:
+    """Wrap a method to run in the background with an optional timeout.
+
+    Returns a new method that will call the original with any args, waiting for upto
+    timeout seconds. This new method blocks on the original and returns the result or
+    None if timeout was reached, along with the thread. You can check thread.is_alive()
+    to determine if a timeout was reached. If an exception is thrown in the thread, we
+    reraise it.
     """
     q: "queue.Queue" = queue.Queue()
 
@@ -1286,7 +1176,7 @@ def read_many_from_queue(
 
 
 def stopwatch_now() -> float:
-    """Get a time value for interval comparisons
+    """Get a time value for interval comparisons.
 
     When possible it is a monotonic clock to prevent backwards time issues.
     """
@@ -1329,7 +1219,7 @@ def prompt_choices(
     input_timeout: Optional[int] = None,
     jupyter: bool = False,
 ) -> str:
-    """Allow a user to choose from a list of options"""
+    """Allow a user to choose from a list of options."""
     for i, choice in enumerate(choices):
         wandb.termlog(f"({i+1}) {choice}")
 
@@ -1351,7 +1241,7 @@ def prompt_choices(
 
 
 def guess_data_type(shape: Sequence[int], risky: bool = False) -> Optional[str]:
-    """Infer the type of data based on the shape of the tensors
+    """Infer the type of data based on the shape of the tensors.
 
     Arguments:
         shape (Sequence[int]): The shape of the data
@@ -1450,7 +1340,6 @@ def parse_sweep_id(parts_dict: dict) -> Optional[str]:
     Returns:
         None or str if there is an error
     """
-
     entity = None
     project = None
     sweep_id = parts_dict.get("name")
@@ -1546,26 +1435,26 @@ def add_import_hook(fullname: str, on_import: Callable) -> None:
 
 
 def host_from_path(path: Optional[str]) -> str:
-    """returns the host of the path"""
+    """Return the host of the path."""
     url = urllib.parse.urlparse(path)
     return str(url.netloc)
 
 
 def uri_from_path(path: Optional[str]) -> str:
-    """returns the URI of the path"""
+    """Return the URI of the path."""
     url = urllib.parse.urlparse(path)
     uri = url.path if url.path[0] != "/" else url.path[1:]
     return str(uri)
 
 
 def is_unicode_safe(stream: TextIO) -> bool:
-    """returns true if the stream supports UTF-8"""
+    """Return True if the stream supports UTF-8."""
     encoding = getattr(stream, "encoding", None)
     return encoding.lower() in {"utf-8", "utf_8"} if encoding else False
 
 
 def _has_internet() -> bool:
-    """Attempts to open a DNS connection to Googles root servers"""
+    """Attempt to open a DNS connection to Googles root servers."""
     try:
         s = socket.create_connection(("8.8.8.8", 53), 0.5)
         s.close()
@@ -1574,7 +1463,10 @@ def _has_internet() -> bool:
         return False
 
 
-def rand_alphanumeric(length: int = 8, rand: Optional[ModuleType] = None) -> str:
+def rand_alphanumeric(
+    length: int = 8, rand: Optional[Union[ModuleType, random.Random]] = None
+) -> str:
+    wandb.termerror("rand_alphanumeric is deprecated, use 'secrets.token_hex'")
     rand = rand or random
     return "".join(rand.choice("0123456789ABCDEF") for _ in range(length))
 
@@ -1583,10 +1475,7 @@ def rand_alphanumeric(length: int = 8, rand: Optional[ModuleType] = None) -> str
 def fsync_open(
     path: Union[pathlib.Path, str], mode: str = "w", encoding: Optional[str] = None
 ) -> Generator[IO[Any], None, None]:
-    """
-    Opens a path for I/O, guaranteeing that the file is flushed and
-    fsynced when the file's context expires.
-    """
+    """Open a path for I/O and guarante that the file is flushed and synced."""
     with open(path, mode, encoding=encoding) as f:
         yield f
 
@@ -1597,7 +1486,7 @@ def fsync_open(
 def _is_kaggle() -> bool:
     return (
         os.getenv("KAGGLE_KERNEL_RUN_TYPE") is not None
-        or "kaggle_environments" in sys.modules  # noqa: W503
+        or "kaggle_environments" in sys.modules
     )
 
 
@@ -1633,21 +1522,19 @@ def _is_py_path(path: str) -> bool:
 
 
 def sweep_config_err_text_from_jsonschema_violations(violations: List[str]) -> str:
-    """Consolidate violation strings from wandb/sweeps describing the ways in which a
-    sweep config violates the allowed schema as a single string.
+    """Consolidate schema violation strings from wandb/sweeps into a single string.
 
     Parameters
     ----------
     violations: list of str
         The warnings to render.
 
-    Returns
+    Returns:
     -------
     violation: str
         The consolidated violation text.
 
     """
-
     violation_base = (
         "Malformed sweep config detected! This may cause your sweep to behave in unexpected ways.\n"
         "To avoid this, please fix the sweep config schema violations below:"
@@ -1661,15 +1548,13 @@ def sweep_config_err_text_from_jsonschema_violations(violations: List[str]) -> s
 
 
 def handle_sweep_config_violations(warnings: List[str]) -> None:
-    """Render warnings from gorilla describing the ways in which a
-    sweep config violates the allowed schema as terminal warnings.
+    """Echo sweep config schema violation warnings from Gorilla to the terminal.
 
     Parameters
     ----------
     warnings: list of str
         The warnings to render.
     """
-
     warning = sweep_config_err_text_from_jsonschema_violations(warnings)
     if len(warnings) > 0:
         term.termwarn(warning)
@@ -1677,7 +1562,6 @@ def handle_sweep_config_violations(warnings: List[str]) -> None:
 
 def _log_thread_stacks() -> None:
     """Log all threads, useful for debugging."""
-
     thread_map = {t.ident: t.name for t in threading.enumerate()}
 
     for thread_id, frame in sys._current_frames().items():
@@ -1745,7 +1629,7 @@ def load_json_yaml_dict(config: str) -> Any:
 
 
 def _parse_entity_project_item(path: str) -> tuple:
-    """Parses paths with the following formats: {item}, {project}/{item}, & {entity}/{project}/{item}.
+    """Parse paths with the following formats: {item}, {project}/{item}, & {entity}/{project}/{item}.
 
     Args:
         path: `str`, input path; must be between 0 and 3 in length.
@@ -1771,7 +1655,9 @@ def _parse_entity_project_item(path: str) -> tuple:
 
 
 def _resolve_aliases(aliases: Optional[Union[str, Iterable[str]]]) -> List[str]:
-    """Takes in `aliases` which can be None, str, or List[str] and returns List[str].
+    """Add the 'latest' alias and ensure that all aliases are unique.
+
+    Takes in `aliases` which can be None, str, or List[str] and returns List[str].
     Ensures that "latest" is always present in the returned list.
 
     Args:
@@ -1780,13 +1666,15 @@ def _resolve_aliases(aliases: Optional[Union[str, Iterable[str]]]) -> List[str]:
     Returns:
         List[str], with "latest" always present.
 
-    Example:
-        aliases = _resolve_aliases(["best", "dev"])
-        assert aliases == ["best", "dev", "latest"]
+    Usage:
 
-        aliases = _resolve_aliases("boom")
-        assert aliases == ["boom", "latest"]
+    ```python
+    aliases = _resolve_aliases(["best", "dev"])
+    assert aliases == ["best", "dev", "latest"]
 
+    aliases = _resolve_aliases("boom")
+    assert aliases == ["boom", "latest"]
+    ```
     """
     aliases = aliases or ["latest"]
 
@@ -1870,7 +1758,7 @@ def ensure_text(
 
 
 def make_artifact_name_safe(name: str) -> str:
-    """Make an artifact name safe for use in artifacts"""
+    """Make an artifact name safe for use in artifacts."""
     # artifact names may only contain alphanumeric characters, dashes, underscores, and dots.
     cleaned = re.sub(r"[^a-zA-Z0-9_\-.]", "_", name)
     if len(cleaned) <= 128:
@@ -1880,7 +1768,7 @@ def make_artifact_name_safe(name: str) -> str:
 
 
 def make_docker_image_name_safe(name: str) -> str:
-    """Make a docker image name safe for use in artifacts"""
+    """Make a docker image name safe for use in artifacts."""
     safe_chars = RE_DOCKER_IMAGE_NAME_CHARS.sub("__", name.lower())
     deduped = RE_DOCKER_IMAGE_NAME_SEPARATOR_REPEAT.sub("__", safe_chars)
     trimmed_start = RE_DOCKER_IMAGE_NAME_SEPARATOR_START.sub("", deduped)
@@ -1889,9 +1777,7 @@ def make_docker_image_name_safe(name: str) -> str:
 
 
 def merge_dicts(source: Dict[str, Any], destination: Dict[str, Any]) -> Dict[str, Any]:
-    """
-    Recursively merge two dictionaries.
-    """
+    """Recursively merge two dictionaries."""
     for key, value in source.items():
         if isinstance(value, dict):
             # get node or create one
